function [train,test,data,hitters] = islr_hitters_split()

    % Get a cleaned hitters dataset as a table
    hitters = islr_get_hitters();
    
    % We need a table with only numercial values so that we can perform a
    % PCA and PLS regression on it. The Hitters has three categorical
    % columns, we have to replace them with numeric values.
    hitters_alt = hitters;  % copy of the original hitters table
    hitters_alt.League = double(categorical(hitters_alt.League) == 'A');  % N -> 0, A -> 1
    hitters_alt.Division = double(categorical(hitters_alt.Division) == 'W');    % E -> 0, W -> 1
    hitters_alt.NewLeague = double(categorical(hitters_alt.NewLeague) == 'A');  % N -> 0, A -> 1
        
    % We want to predict the `Salary` column, hence we need to remove it
    % from the set of regressors so that we can call call the matrix
    % form of `fitlm(X,y)` ... but the salary is needed as a response `y` 
    % so we store it to a separate variable.
    hitters_salary = hitters_alt.Salary;
    hitters_alt.Salary = [];
    
    % Convert the preprocessed table into a data matrix
    tbl_data = table2array(hitters_alt);
        
    % Standardize the std deviation of regressors for PCA and PLS
    stdevs = std(tbl_data, 1);
    std_data = tbl_data ./ stdevs;
    
    % Finally, split the dataset into a training and testing subset of
    % approximately same size.
    % We will use boolean indexing!
    num_records = size(tbl_data, 1);  % the number of rows in the data
    train_idx = false(num_records, 1);  % allocate logical array for indexing
    y = randsample(num_records, floor(num_records/2));  % randomly select N/2 indexes from 1...N
    train_idx(y) = true;  % the positions where train_idx==true are the training records
    test_idx = ~train_idx;
    
    % Store the training and testing dataset AS MATLAB STRUCTURES
    train.X = std_data(train_idx,:);
    train.y = hitters_salary(train_idx);
    test.X = std_data(test_idx,:);
    test.y = hitters_salary(test_idx);
    
    data.X = tbl_data;  % this is not standardised
    data.y = hitters_salary;
    
end
